<?php

/**
 * Fills in the body of the given node.
 */
function save($tnode, $new_nid, $parent_of, $mode) {
    
    if (DEBUG > 2) { 
        echo "saving node '" . $tnode->title . "' ";
        echo "(id = " . $tnode->id .", mode = $mode)\n";

        // set up metadata
        $nodeid = preg_replace('@^(node-)(\d+)$@', '\2', $tnode->id);
        $nidinfo  = "  nid:$nodeid\n";
        $nidinfo .= "  title:$tnode->title\n";
        $nidinfo .= "  md5:".$tnode->get_md5()."\n";
        $nidinfo .= "  weight:".$tnode->get_weight()."\n";
        $nidinfo .= "  depth:".$tnode->get_depth()."\n";
        $nidinfo .= "  parent:".$tnode->get_parent()."\n";
        
        echo "<pre style=\"font-family: courier; font-size: 8pt;\">";
        echo "$nidinfo</pre>"; 
    }

    if ($mode == 'update') {
        update($tnode);
    }
    else if ($mode == 'insert') {
        create($tnode);
    }
    else {
        // Write node body
    }
}

/**
 *
 */
function create($tnode) {
    global $user;
    global $parent_of;
    global $new_nid;

    $node->body = $tnode->body;
    $node->title = $tnode->title;
    $node->weight = $tnode->weight;

    $node->nodetype = $tnode->nodetype;
    $node->author = $tnode->author;
    $node->uid = $tnode->uid;
    $node->created = $tnode->created;
    $node->status = $tnode->status;
    $node->format = $tnode->format;
    $node->sticky = $tnode->sticky;
    $node->promote = $tnode->promote;

    // $node->uid = $user->uid;
    // $node->create = time();

    $node->nid = node_save($node);
    // get the new nid, store it hashed by old nid:
    $new_nid[$tnode->id] = $node->nid;
    // record the parent-child of the node, 
    // based on the existing ids
    $parent_of[$tnode->id] = $tnode->parent;

    if (DEBUG > 1)  { echo "created: nid = " . $node->nid. "\n"; } ;
    return ($node->nid);
}


/**
 *
 */
function update($tnode) {

    // We need to deal with case where tnode does not have an id.
    // In this case, create the node rather than updating
    // an existing node.

    // echo "update: tnode->id = " . $tnode->id. "<br/>\n"; 

    if (!isset($tnode->id) || $tnode->id == 0) {
        $tnode->id = create($tnode);
        if (DEBUG > 1)  { echo "update: created new node with nid = " . $node->nid. "\n"; };
        // echo "update: created new node with nid = " . $tnode->id. "<br/>\n";

        $log = "\nInserted on " . date("D F j, Y") . " at " . date("G:i:s T") . "<br/>\n";

        $book_sql = 
            db_rewrite_sql(
                           "UPDATE {book} ".
                           "SET ".
                           "  weight=%d, ".
                           "  parent=%d, ".
                           "  log='%s' ".
                           "WHERE ".
                           "  nid = %d"
                           );

        $result = db_query($book_sql,
                           $tnode->get_weight(),
                           $tnode->parent,
                           $tnode->log . $log,
                           $tnode->id
                           );
    }
    else {
        $timestamp = time();
        $log = "\nUpdated on " . date("D F j, Y") . " at " . date("G:i:s T") . "<br/>\n";
        $node_sql = 
            db_rewrite_sql(
                           "UPDATE {node} ".
                           "SET".
                           "  type=%s, ".
                           "  author=%s, ".
                           "  uid=%d, ".
                           "  created=%d, ".
                           "  status=%d, ".
                           "  format=%d, ".
                           "  sticky=%d, ".
                           "  promote=%d, ".
                           "  weight=%d, ".
                           "  title='%s',".
                           "  body='%s',".
                           "  changed=%d ".
                           "WHERE".
                           "  nid=%d"
                           );
        
        $book_sql = 
            db_rewrite_sql(
                           "UPDATE {book} ".
                           "SET".
                           "  weight=%d,".
                           "  parent=%d,".
                           "  log='%s' ".
                           "WHERE".
                           "  nid=%d "
                           );

        $result = db_query($node_sql, 
                           $tnode->nodetype,
                           $tnode->author,
                           $tnode->uid,
                           $tnode->created,
                           $tnode->status,
                           $tnode->format,
                           $tnode->sticky,
                           $tnode->promote,
                           $tnode->get_weight(),
                           $tnode->title,
                           $tnode->body,
                           $timestamp,
                           $tnode->id
                           );
        
        $result = db_query($book_sql,
                           $tnode->get_weight(),
                           $tnode->parent,
                           $tnode->log . $log,
                           $tnode->id
                           );
        
        // if (TRUE) {
        if (DEBUG > 2) {
            echo "<pre style=\"font-family: courier; font-size: 8pt;\">";
            echo "db_query(\"$node_sql\", ".
                "'$tnode->title', ".
                "tnode->body, ".
                "$timestamp, ".
                "$tnode->id)<br/>\n";
            echo "db_query(\"$book_sql\", ".$tnode->get_weight().", ". $tnode->parent.", $tnode->id)<br/>\n";
            echo "</pre>\n";
        }
    }
}
    
# at end, if inserting new records iterate over new_nid
function make_links($parent_of, $new_nid) {

    global $parent_of;
    global $new_nid;

    if (DEBUG > 0) { echo "make_links()<br/>"; };
    if (DEBUG > 4) { 
        echo "<pre>\n"; 
        print_r($parent_of);
        print_r($new_nid);
        echo "</pre>\n"; 
    };

    $book_sql = 
        db_rewrite_sql(
                       "UPDATE {book} ".
                       "SET".
                       "  weight=%d, ".
                       "  parent=%d, ".
                       "  log='%s' ".
                       "WHERE".
                       "  nid=%d "
                       );
    
    foreach ($new_nid as $nid => $new_value) {
        $node = node_load(array('nid' => $new_value));
        $node->nid = $new_value;
        $this_parent = $new_nid[$parent_of[$nid]];
        $node->parent = $this_parent;

        $log = "Imported on " . date("D F j, Y") . " at " . date("G:i:s T") . "<br/>";
        $log .= "parent[$nid ($new_value)] = " .$parent_of[$nid]. " ($this_parent)";
        $log .= $node->log;
    
        $result = db_query($book_sql,
                           $node->weight,
                           $this_parent,
                           $log,
                           $node->nid
                           );
        
        if (DEBUG > 0) { echo "parent[$nid ($new_value)] = " .$parent_of[$nid]. " ($this_parent)<br/>"; }
    }
}

?>
